## [0.1.3] - 2024-09-24
### Added
- Incorporate various functionality from the [OOI Data Explorations](https://github.com/oceanobservatories/ooi-data-explorations/tree/master/python) 
  repository. Mainly from common.py.

### Changed
- Refactored to better organize the classes and modules within yooink
- Updated the Jupyter notebook demos to handle these changes and updates.
